@@ -189,25 +189,23 @@ extern struct card {
 } card;
 
 
-Display	*dpy;
-int	screen;
-
 #ifdef useXview
-Window table;
-Frame mainwindow;
-Panel buttonbox;
-Canvas canvas;
-Menu cmenu;
-Event *bp_event;
+extern Window table;
+extern Frame mainwindow;
+extern Panel buttonbox;
+extern Canvas canvas;
+extern Menu cmenu;
+extern Event *bp_event;
 #else
-Window	table, mainwindow;
+extern Window table, mainwindow;
 #endif
 
-unsigned long	blackpixel;
-unsigned long	whitepixel;
-GC	blackgc;
-GC	whitegc;
-
+extern Display *dpy;
+extern int screen;
+extern unsigned long blackpixel;
+extern unsigned long whitepixel;
+extern GC blackgc;
+extern GC whitegc;
 
 #ifdef useXlib
 #define	TABLE_BW	2
@@ -252,7 +250,7 @@ extern struct confirm {
     Window win;
 } confirm;
 
-Window finished_win;
+extern Window finished_win;
 #define FINISHED_W	100
 #define FINISHED_H	 50
 
