@@ -13,7 +13,16 @@
 
 #include <time.h>
 #include <limits.h>	/* for INT_MAX */
+#include <math.h>
 
+/* RNG patch: */
+int rng = 1;
+static int myrand(int limit) {
+    /* select one of the RNGs. */
+    return rng ?
+	(int)(((double)(prand()) / (double)PRANDMAX) * (double)limit)
+	    : prand() % limit;
+}
 
 static Move Klondike_deal_cards(void) {
     int rem = CARDS_ON_PILE(IDECK);
@@ -63,7 +72,7 @@ Move SlotShuffle(int fwd) {
     sprand(game.seed);
     for (i = 0; i < num; ++i) {
 	int j;
-	j = prand() % num;
+	j = myrand(num);
 	if (j < i)	/* some correction */
 	    j = i;
 	tab[i] = j;
@@ -321,6 +330,8 @@ static void shuffle(void) {
     int i, d, v, c;
     int tmp[MAXCARDS];
 
+    if (game.graphic)
+	show_message(" ");
     i = 0;
     for (d = 0; d < rules.numdecks; ++d)
 	for (v = 0; v < rules.cards_per_color; ++v)
@@ -331,10 +342,10 @@ static void shuffle(void) {
     while (i < rules.numcards)
 	tmp[i++] = JOKER + c++;
     while (c < rules.numjokers)
-	tmp[prand() % rules.numcards] = JOKER + c++;	/* subst old cards */
+	tmp[myrand(rules.numcards)] = JOKER + c++;	/* subst old cards */
 
     for (i = rules.numcards; i; --i) {
-	v = ((int)prand() & INT_MAX) % i;
+	v = myrand(i);
 	/* printf("rand() = %d\n", v); */
 	/* look for the vth non-empty card in tmp */
 	c = -1;
@@ -656,7 +667,7 @@ Move give_new_cards(void) {
 extern struct rules Spider_rules, Gypsy_rules, Klondike_rules, modSpider_rules;
 extern struct rules Seahaven_rules, FreeCell_rules, IdiotsDelight_rules,
     MonteCarlo_rules, MidnightOil_rules, Calculation_rules, Michaels_rules,
-    Canfield_rules, Royal_rules, Bakers_rules;
+    Canfield_rules, modCanfield_rules, Royal_rules, Bakers_rules;
 
 struct game game;
 struct rules rules;
@@ -671,7 +682,7 @@ struct rules *rulepool[] = {
     &MonteCarlo_rules,
     &MidnightOil_rules,
     &Calculation_rules,
-    &modSpider_rules,
+    &modCanfield_rules,
     &Michaels_rules,
     &Canfield_rules,
     &Royal_rules,
